From: Robert Rothenberg <rrwo@cpan.org>
Date: Tue, 24 Jun 2025 13:21:53 +0100
Subject: [PATCH] Change use of inet_aton back to inet_pton

This is a security issue for Net::IP::LPM version 1.10 for Perl that
reverts changes which used inet_aton instead of inet_pton.

The inet_aton function on most sytems allows alternative formats for
IPv4 addresses, including using octal numbers indicated by leading 0s.

The rationale for the change was "buggy implementation of inet_pton in
Ubuntu" from August 2015. It is not clear what the exact details of
that issue are. This patch assumes that the issue has been fixed since
then.

---
 lib/Net/IP/LPM.pm  | 10 +++++-----
 t/02-performance.t |  4 ++--
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/lib/Net/IP/LPM.pm b/lib/Net/IP/LPM.pm
index ef9d6cc..ee3bad7 100644
--- a/lib/Net/IP/LPM.pm
+++ b/lib/Net/IP/LPM.pm
@@ -10,9 +10,9 @@ require Exporter;

 #use Socket qw( AF_INET );
 #use Socket6 qw( inet_ntop inet_pton AF_INET6 );
-use if $] <  5.014000, Socket  => qw(inet_aton AF_INET);
+use if $] <  5.014000, Socket  => qw(AF_INET);
 use if $] <  5.014000, Socket6 => qw(inet_ntop inet_pton AF_INET6);
-use if $] >= 5.014000, Socket  => qw(inet_ntop inet_pton inet_aton AF_INET6 AF_INET);
+use if $] >= 5.014000, Socket  => qw(inet_ntop inet_pton AF_INET6 AF_INET);
 #use Data::Dumper;

 #our @ISA = qw(DB_File);
@@ -139,7 +139,7 @@ sub format_addr {
 		return undef;
 	}

-	if ((my $addr_bin = inet_aton($addr))) {
+	if ((my $addr_bin = inet_pton(AF_INET, $addr))) {
 		return $addr_bin;
 	} else {
 		return inet_pton(AF_INET6, $addr);
@@ -165,7 +165,7 @@ sub add {

 	($prefix, $prefix_len) = split('/', $prefix);

-	if (! ($prefix_bin = inet_aton($prefix)) ) {
+	if (! ($prefix_bin = inet_pton(AF_INET, $prefix)) ) {
 		$prefix_bin = inet_pton(AF_INET6, $prefix);
 	}

@@ -200,7 +200,7 @@ sub lookup {
 	my ($self, $addr) = @_;
 	my $addr_bin;

-	if (! ($addr_bin = inet_aton($addr)) ) {
+	if (! ($addr_bin = inet_pton(AF_INET, $addr)) ) {
 		$addr_bin = inet_pton(AF_INET6, $addr);
 	}

diff --git a/t/02-performance.t b/t/02-performance.t
index ba3b585..28f611d 100644
--- a/t/02-performance.t
+++ b/t/02-performance.t
@@ -10,9 +10,9 @@ BEGIN { use_ok('Net::IP::LPM') };

 #use Socket qw( AF_INET );
 #use Socket6 qw( inet_ntop inet_pton AF_INET6 );
-use if $] <  5.014000, Socket  => qw(inet_aton AF_INET);
+use if $] <  5.014000, Socket  => qw(AF_INET);
 use if $] <  5.014000, Socket6 => qw(inet_ntop inet_pton AF_INET6);
-use if $] >= 5.014000, Socket  => qw(inet_ntop inet_pton inet_aton AF_INET6 AF_INET);
+use if $] >= 5.014000, Socket  => qw(inet_ntop inet_pton AF_INET6 AF_INET);

 #########################
